@@ -34,7 +34,6 @@ my $schema_attributes_spec = {
   select_implicitly_for => {type => SCALAR,          default  => ''                                       },
   autolimit_firstrow    => {type => BOOLEAN,         optional => 1                                        },
   db_schema             => {type => SCALAR,          optional => 1                                        },
-  resultAs_classes      => {type => ARRAYREF,        optional => 1                                        },
   handleError_policy    => {type => SCALAR,          default  => 'combine', regex => qr(^(if_absent
                                                                                          |combine
                                                                                          |override
@@ -64,9 +63,6 @@ sub new {
   # default SQLA
   $self->{sql_abstract} ||= $metadm->sql_abstract_class->new($metadm->sql_abstract_args);
 
-  # default resultAs_classes
-  $self->{resultAs_classes} ||= mro::get_linear_isa($class);
-
   # from now on, singleton mode will be forbidden
   $metadm->{singleton} = undef;
 
@@ -85,10 +81,17 @@ foreach my $accessor (grep {$_ ne 'dbh'} keys %$schema_attributes_spec) {
     ref $self or $self = $self->singleton;
 
     if (@_) {
-      my ($new_val) = validate_with(params      => \@_,
-                                    spec        => [ $schema_attributes_spec->{$accessor} ],
-                                    allow_extra => 0);
-      $self->{$accessor} = $new_val;
+      if (not defined $_[0]) { # $schema->$attribute(undef) means deleting that attribute in $schema
+        delete $self->{$accessor};
+      }
+      else {
+        my ($new_val) = validate_with(params      => \@_,
+                                      spec        => [ $schema_attributes_spec->{$accessor} ],
+                                      allow_extra => 0,
+                                      called      => $accessor,
+                                     );
+        $self->{$accessor} = $new_val;
+      }
     }
     return $self->{$accessor};
   };
@@ -470,13 +473,15 @@ This is the parent class for all schema classes created through
 
 =head1 CONSTRUCTOR
 
-See L<DBIx::DataModel::Doc::Reference/Schema>
+See L<DBIx::DataModel::Doc::Reference/Schema::new()>
 
+=head1 ATTRIBUTES
+
+See L<DBIx::DataModel::Doc::Reference/Schema attributes>
 
 =head1 METHODS
 
-Methods are documented in 
-L<DBIx::DataModel::Doc::Reference|DBIx::DataModel::Doc::Reference>.
+See L<DBIx::DataModel::Doc::Reference/Other schema methods>.
 
 =head2 Delegated methods
 
